@@ -19,43 +19,48 @@
  */
 
 #include "test_iresourcerepository.h"
-#include <QTest>
-#include <QSignalSpy>
 #include <QObject>
+#include <QSignalSpy>
+#include <QTest>
 
-#include "core/resourcerepository.h"
-#include "core/contributorrepository.h"
-#include "core/language.h"
-#include "core/icourse.h"
-#include "core/unit.h"
 #include "../src/settings.h"
+#include "core/contributorrepository.h"
+#include "core/icourse.h"
+#include "core/language.h"
+#include "core/resourcerepository.h"
+#include "core/unit.h"
+
+TestIResourceRepository::TestIResourceRepository()
+    : m_repositoryLocation(QUrl::fromLocalFile(qApp->applicationDirPath() + "/../autotests/integrationtests/data/"))
+{
+    qDebug() << "Running test with repository root:" << m_repositoryLocation;
+}
 
 void TestIResourceRepository::init()
 {
     // check that test data is deployed at the expected location
-    QVERIFY(QFile::exists("data/courses/de/de.xml"));
-    QVERIFY(QFile::exists("data/courses/fr/fr.xml"));
+    QVERIFY(QFile::exists(m_repositoryLocation.toLocalFile() + "/courses/de/de.xml"));
+    QVERIFY(QFile::exists(m_repositoryLocation.toLocalFile() + "/courses/fr/fr.xml"));
 }
 
 void TestIResourceRepository::resourceRepository()
 {
-    ResourceRepository repository(QUrl::fromLocalFile("data/courses/"));
-    QCOMPARE(repository.storageLocation(), "data/courses/");
+    ResourceRepository repository(QUrl::fromLocalFile(m_repositoryLocation.toLocalFile() + "/courses/"));
+    QCOMPARE(repository.storageLocation(), QUrl::fromLocalFile(m_repositoryLocation.toLocalFile() + "/courses/"));
     performInterfaceTests(&repository);
 }
 
 void TestIResourceRepository::contributorRepository()
 {
-    ContributorRepository repository;
-    repository.setStorageLocation("data/contributorrepository/"); // contributor repository requires subdirectory "courses"
-    QCOMPARE(repository.storageLocation(), "data/contributorrepository/");
+    ContributorRepository repository(QUrl::fromLocalFile(m_repositoryLocation.toLocalFile() + "/contributorrepository/")); // contributor repository requires subdirectory "courses"
+    QCOMPARE(repository.storageLocation(), QUrl::fromLocalFile(m_repositoryLocation.toLocalFile() + "/contributorrepository/"));
     performInterfaceTests(&repository);
 }
 
 void TestIResourceRepository::performInterfaceTests(IResourceRepository *interface)
 {
     QVERIFY(interface->languages().count() > 0); // automatically load languages
-    QCOMPARE(interface->courses().count(), 0); // load courses only on demand
+    QCOMPARE(interface->courses().count(), 0);   // load courses only on demand
 
     // test adding
     QSignalSpy spyAboutToBeAdded(dynamic_cast<QObject *>(interface), SIGNAL(courseAboutToBeAdded(std::shared_ptr<ICourse>, int)));
@@ -83,9 +88,10 @@ void TestIResourceRepository::performInterfaceTests(IResourceRepository *interfa
             break;
         }
     }
-    QVERIFY(german != nullptr); // ensure that German language was found
+    QVERIFY(german != nullptr);                            // ensure that German language was found
     QCOMPARE(interface->courses(german->id()).count(), 1); // there is exactly one German course
-    QCOMPARE(interface->courses(nullptr).count(), 2); // all courses in total are 2
+    QCOMPARE(interface->courses(nullptr).count(), 2);      // all courses in total are 2
+    QVERIFY(interface->courses().first()->units().size() > 0);
 }
 
 QTEST_GUILESS_MAIN(TestIResourceRepository)
