@@ -28,7 +28,6 @@ class QSqlDatabase;
 
 namespace LearnerProfile
 {
-
 class Learner;
 class LearningGoal;
 
@@ -46,11 +45,11 @@ public:
      * Default constructor, which sets a default database path at
      * DataLocation + learnerdata.db
      */
-    explicit Storage(QObject* parent = nullptr);
+    explicit Storage(QObject *parent = nullptr);
     /**
      * \note this constructor is tailored for unit tests
      */
-    explicit Storage(const QString &databasePath, QObject* parent = nullptr);
+    explicit Storage(const QString &databasePath, QObject *parent = nullptr);
     QString errorMessage() const;
 
     /**
@@ -60,31 +59,25 @@ public:
     bool storeProfile(Learner *learner);
     bool removeProfile(Learner *learner);
     bool removeRelation(Learner *learner, LearningGoal *goal);
-    QList<Learner *> loadProfiles(QList< LearnerProfile::LearningGoal* > goals);
+    QList<Learner *> loadProfiles(QList<LearnerProfile::LearningGoal *> goals);
     bool storeGoal(LearningGoal *goal);
     QList<LearningGoal *> loadGoals();
-    bool storeProgressLog(Learner *learner, LearningGoal *goal,
-                       const QString &container, const QString &item, int payload,
-                       const QDateTime &time);
+    bool storeProgressLog(Learner *learner, LearningGoal *goal, const QString &container, const QString &item, int payload, const QDateTime &time);
     /**
      * Load list of progress values for specified item
      * \return list of date/payload values for this item
      */
-    QList<QPair<QDateTime,int>> readProgressLog(Learner *learner, LearningGoal *goal,
-                       const QString &container, const QString &item);
-    bool storeProgressValue(Learner *learner, LearningGoal *goal,
-                       const QString &container, const QString &item, int payload);
+    QList<QPair<QDateTime, int>> readProgressLog(Learner *learner, LearningGoal *goal, const QString &container, const QString &item);
+    bool storeProgressValue(Learner *learner, LearningGoal *goal, const QString &container, const QString &item, int payload);
     /**
      * Load list of progress values for specified container
      * \return list of item/payload values for all items in container
      */
-    QHash<QString, int> readProgressValues(Learner *learner, LearningGoal *goal,
-                       const QString &container);
+    QHash<QString, int> readProgressValues(Learner *learner, LearningGoal *goal, const QString &container);
     /**
      * Load payload value of specified item. If no value is found, \return -1
      */
-    int readProgressValue(Learner *learner, LearningGoal *goal,
-                       const QString &container, const QString &item);
+    int readProgressValue(Learner *learner, LearningGoal *goal, const QString &container, const QString &item);
 
 Q_SIGNALS:
     void errorMessageChanged();
