@@ -17,3 +17,5 @@
 
 #include "artikulate_debug.h"
 Q_LOGGING_CATEGORY(ARTIKULATE_LOG, "log_artikulate")
+Q_LOGGING_CATEGORY(ARTIKULATE_CORE, "articulate.core")
+Q_LOGGING_CATEGORY(ARTIKULATE_PARSER, "articulate.parser")
