@@ -20,5 +20,7 @@
 
 #include <QLoggingCategory>
 Q_DECLARE_LOGGING_CATEGORY(ARTIKULATE_LOG)
+Q_DECLARE_LOGGING_CATEGORY(ARTIKULATE_CORE)
+Q_DECLARE_LOGGING_CATEGORY(ARTIKULATE_PARSER)
 
 #endif
