@@ -23,12 +23,13 @@
 
 #include "artikulatecore_export.h"
 #include "ieditablerepository.h"
-#include <memory>
-#include <QObject>
-#include <QMap>
 #include <QHash>
-#include <QVector>
+#include <QMap>
+#include <QObject>
 #include <QStringList>
+#include <QUrl>
+#include <QVector>
+#include <memory>
 
 #include "liblearnerprofile/src/learninggoal.h"
 
@@ -37,7 +38,6 @@ class EditableCourseResource;
 class LanguageResource;
 class Language;
 class ICourse;
-class QUrl;
 
 /**
  * @class ContributorRepository
@@ -49,10 +49,11 @@ class ARTIKULATECORE_EXPORT ContributorRepository : public IEditableRepository
     Q_INTERFACES(IResourceRepository)
     Q_INTERFACES(IEditableRepository)
 
-    Q_PROPERTY(QString repositoryUrl READ storageLocation NOTIFY repositoryChanged)
+    Q_PROPERTY(QUrl repositoryUrl READ storageLocation WRITE setStorageLocation NOTIFY repositoryChanged)
 
 public:
     explicit ContributorRepository();
+    explicit ContributorRepository(QUrl storageLocation);
     ~ContributorRepository() override;
 
     /**
@@ -68,13 +69,13 @@ public:
     /**
      * \return path to working repository, if one is set
      */
-    QString storageLocation() const override;
+    QUrl storageLocation() const override;
 
     /**
      * Set path to central storage location
      * \param path the path to the storage location directory
      */
-    void setStorageLocation(const QString &path);
+    void setStorageLocation(const QUrl &path);
 
     QVector<std::shared_ptr<ILanguage>> languages() const override;
 
@@ -86,7 +87,7 @@ public:
     /**
      * \return language by \p learningGoal
      */
-    Q_INVOKABLE ILanguage * language(LearnerProfile::LearningGoal* learningGoal) const;
+    Q_INVOKABLE ILanguage *language(LearnerProfile::LearningGoal *learningGoal) const;
 
     QVector<std::shared_ptr<ICourse>> courses() const override;
     QVector<std::shared_ptr<ICourse>> courses(const QString &languageId) const override;
@@ -149,7 +150,7 @@ public:
      *
      * \return created course
      */
-    Q_INVOKABLE IEditableCourse * createCourse(std::shared_ptr<ILanguage> language, std::shared_ptr<SkeletonResource> skeleton);
+    Q_INVOKABLE IEditableCourse *createCourse(std::shared_ptr<ILanguage> language, std::shared_ptr<SkeletonResource> skeleton);
 
     /**
      * Adds skeleton resource to resource manager
@@ -170,14 +171,14 @@ public:
 
 Q_SIGNALS:
     void languageResourceAdded();
-    void languageResourceAboutToBeAdded(std::shared_ptr<ILanguage>,int);
+    void languageResourceAboutToBeAdded(std::shared_ptr<ILanguage>, int);
     void languageResourceRemoved();
     void languageResourceAboutToBeRemoved(int);
     void repositoryChanged();
     void skeletonAdded();
-    void skeletonAboutToBeAdded(ICourse*,int);
+    void skeletonAboutToBeAdded(ICourse *, int);
     void skeletonRemoved();
-    void skeletonAboutToBeRemoved(int,int);
+    void skeletonAboutToBeRemoved(int, int);
     void languageCoursesChanged();
 
 private:
@@ -186,9 +187,9 @@ private:
      * for this application.
      */
     void loadLanguageResources();
-    QString m_storageLocation;
+    QUrl m_storageLocation;
     QVector<std::shared_ptr<ILanguage>> m_languages;
-    QMap<QString, QVector<std::shared_ptr<EditableCourseResource>> > m_courses; //!> (language-id, course-resource)
+    QMap<QString, QVector<std::shared_ptr<EditableCourseResource>>> m_courses; //!> (language-id, course-resource)
     QVector<std::shared_ptr<IEditableCourse>> m_skeletonResources;
     QStringList m_loadedResources;
 };
