@@ -22,13 +22,14 @@
 #define ICOURSE_H
 
 #include "artikulatecore_export.h"
-#include <QObject>
 #include <QMap>
+#include <QObject>
 #include <QUrl>
 #include <memory>
 
 class QString;
 class ILanguage;
+class IUnit;
 class Unit;
 class Phoneme;
 
@@ -39,6 +40,7 @@ class ARTIKULATECORE_EXPORT ICourse : public QObject
     Q_PROPERTY(QString title READ title NOTIFY titleChanged)
     Q_PROPERTY(QString i18nTitle READ i18nTitle NOTIFY titleChanged)
     Q_PROPERTY(QString description READ description NOTIFY descriptionChanged)
+    Q_PROPERTY(QString languageTitle READ languageTitle CONSTANT)
 
 public:
     virtual ~ICourse() = default;
@@ -47,6 +49,7 @@ public:
     virtual QString title() const = 0;
     virtual QString i18nTitle() const = 0;
     virtual QString description() const = 0;
+    virtual QString languageTitle() const = 0;
     virtual std::shared_ptr<ILanguage> language() const = 0;
     /**
      * @brief Lazy loading unit list
@@ -68,9 +71,9 @@ Q_SIGNALS:
     void descriptionChanged();
     void languageChanged();
     void unitAdded();
-    void unitAboutToBeAdded(std::shared_ptr<Unit>,int);
+    void unitAboutToBeAdded(std::shared_ptr<Unit> unit, int index);
     void unitsRemoved();
-    void unitsAboutToBeRemoved(int,int);
+    void unitsAboutToBeRemoved(int, int);
 };
 
 Q_DECLARE_INTERFACE(ICourse, "com.kde.artikulate.ICourse/1.0")
