@@ -20,12 +20,12 @@
 
 #include "resourcerepository.h"
 #include "artikulate_debug.h"
-#include "resources/courseresource.h"
 #include "core/language.h"
-#include <QStandardPaths>
-#include <QUrl>
+#include "resources/courseresource.h"
 #include <QDir>
 #include <QDirIterator>
+#include <QStandardPaths>
+#include <QUrl>
 
 ResourceRepository::ResourceRepository()
     : ResourceRepository(QUrl::fromLocalFile(QStandardPaths::standardLocations(QStandardPaths::DataLocation).constFirst() + QStringLiteral("/courses/")))
@@ -34,8 +34,9 @@ ResourceRepository::ResourceRepository()
 
 ResourceRepository::ResourceRepository(const QUrl &storageLocation)
     : IResourceRepository()
-    , m_storageLocation(storageLocation.toLocalFile())
+    , m_storageLocation(storageLocation)
 {
+    qCDebug(ARTIKULATE_CORE()) << "Repository created from with location" << m_storageLocation;
     // load language resources
     // all other resources are only loaded on demand
     QDir dir(":/artikulate/languages/");
@@ -52,7 +53,7 @@ ResourceRepository::ResourceRepository(const QUrl &storageLocation)
 
 ResourceRepository::~ResourceRepository() = default;
 
-QString ResourceRepository::storageLocation() const
+QUrl ResourceRepository::storageLocation() const
 {
     return m_storageLocation;
 }
@@ -112,7 +113,7 @@ void ResourceRepository::reloadCourses()
         }
     };
 
-    QDir rootDirectory = QDir(m_storageLocation);
+    QDir rootDirectory = QDir(m_storageLocation.toLocalFile());
     QDirIterator it(rootDirectory, QDirIterator::Subdirectories);
     qCInfo(ARTIKULATE_CORE()) << "Loading courses from" << rootDirectory.absolutePath();
 
