@@ -19,22 +19,21 @@
  */
 
 #include "courseparser.h"
-#include "core/icourse.h"
-#include "core/language.h"
-#include "core/unit.h"
-#include "core/phrase.h"
-#include "core/phoneme.h"
 #include "artikulate_debug.h"
+#include "core/ieditablecourse.h"
+#include "core/language.h"
+#include "core/phoneme.h"
+#include "core/phrase.h"
+#include "core/unit.h"
 
-#include <QDomDocument>
+#include <KTar>
 #include <QDir>
+#include <QDomDocument>
 #include <QFile>
 #include <QFileInfo>
 #include <QXmlSchema>
-#include <QXmlStreamReader>
 #include <QXmlSchemaValidator>
-#include <KTar>
-
+#include <QXmlStreamReader>
 
 QXmlSchema CourseParser::loadXmlSchema(const QString &schemeName)
 {
@@ -69,9 +68,9 @@ QDomDocument CourseParser::loadDomDocument(const QUrl &path, const QXmlSchema &s
     return document;
 }
 
-std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete)
+std::vector<std::shared_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete)
 {
-    std::vector<std::unique_ptr<Unit>> units;
+    std::vector<std::shared_ptr<Unit>> units;
 
     QFileInfo info(path.toLocalFile());
     if (!info.exists()) {
@@ -86,7 +85,7 @@ std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QV
         xml.readNextStartElement();
 
         while (!xml.atEnd() && !xml.hasError()) {
-            bool elementOk{ false };
+            bool elementOk {false};
             QXmlStreamReader::TokenType token = xml.readNext();
 
             if (token == QXmlStreamReader::StartDocument) {
@@ -115,13 +114,12 @@ std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QV
     return units;
 }
 
-std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete, bool &ok)
+std::shared_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete, bool &ok)
 {
-    std::unique_ptr<Unit> unit(new Unit);
+    std::shared_ptr<Unit> unit = Unit::create();
     ok = true;
 
-    if (xml.tokenType() != QXmlStreamReader::StartElement
-        && xml.name() == "unit") {
+    if (xml.tokenType() != QXmlStreamReader::StartElement && xml.name() == "unit") {
         qCWarning(ARTIKULATE_PARSER()) << "Expected to parse 'unit' element, aborting here";
         return unit;
     }
@@ -129,11 +127,11 @@ std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl
     xml.readNext();
     while (!(xml.tokenType() == QXmlStreamReader::EndElement && xml.name() == "unit")) {
         if (xml.tokenType() == QXmlStreamReader::StartElement) {
-            bool elementOk{ false };
+            bool elementOk {false};
             if (xml.name() == "id") {
                 unit->setId(parseElement(xml, elementOk));
                 ok &= elementOk;
-            }  else if (xml.name() == "foreignId") {
+            } else if (xml.name() == "foreignId") {
                 unit->setForeignId(parseElement(xml, elementOk));
                 ok &= elementOk;
             } else if (xml.name() == "title") {
@@ -141,13 +139,10 @@ std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl
                 ok &= elementOk;
             } else if (xml.name() == "phrases") {
                 // nothing to do
-            }
-            else if (xml.name() == "phrase") {
+            } else if (xml.name() == "phrase") {
                 auto phrase = parsePhrase(xml, path, phonemes, elementOk);
                 if (elementOk && (!skipIncomplete || !phrase->soundFileUrl().isEmpty())) {
-                    unit->addPhrase(phrase);
-                } else {
-                    phrase->deleteLater();
+                    unit->addPhrase(phrase, unit->phrases().size());
                 }
                 ok &= elementOk;
             } else {
@@ -162,13 +157,12 @@ std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl
     return unit;
 }
 
-Phrase * CourseParser::parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool &ok)
+std::shared_ptr<Phrase> CourseParser::parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool &ok)
 {
-    Phrase * phrase = new Phrase;
+    std::shared_ptr<Phrase> phrase = Phrase::create();
     ok = true;
 
-    if (xml.tokenType() != QXmlStreamReader::StartElement
-        && xml.name() == "phrase") {
+    if (xml.tokenType() != QXmlStreamReader::StartElement && xml.name() == "phrase") {
         qCWarning(ARTIKULATE_PARSER()) << "Expected to parse 'phrase' element, aborting here";
         ok = false;
         return phrase;
@@ -177,7 +171,7 @@ Phrase * CourseParser::parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVec
     xml.readNext();
     while (!(xml.tokenType() == QXmlStreamReader::EndElement && xml.name() == "phrase")) {
         if (xml.tokenType() == QXmlStreamReader::StartElement) {
-            bool elementOk{ false };
+            bool elementOk {false};
             if (xml.name() == "id") {
                 phrase->setId(parseElement(xml, elementOk));
                 ok &= elementOk;
@@ -208,13 +202,13 @@ Phrase * CourseParser::parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVec
             } else if (xml.name() == "type") {
                 const QString type = parseElement(xml, elementOk);
                 if (type == "word") {
-                    phrase->setType(Phrase::Word);
+                    phrase->setType(IPhrase::Type::Word);
                 } else if (type == "expression") {
-                    phrase->setType(Phrase::Expression);
+                    phrase->setType(IPhrase::Type::Expression);
                 } else if (type == "sentence") {
-                    phrase->setType(Phrase::Sentence);
+                    phrase->setType(IPhrase::Type::Sentence);
                 } else if (type == "paragraph") {
-                    phrase->setType(Phrase::Paragraph);
+                    phrase->setType(IPhrase::Type::Paragraph);
                 }
                 ok &= elementOk;
             } else if (xml.name() == "editState") {
@@ -244,8 +238,7 @@ QStringList CourseParser::parsePhonemeIds(QXmlStreamReader &xml, bool &ok)
     QStringList ids;
     ok = true;
 
-    if (xml.tokenType() != QXmlStreamReader::StartElement
-        && xml.name() == "phonemes") {
+    if (xml.tokenType() != QXmlStreamReader::StartElement && xml.name() == "phonemes") {
         qCWarning(ARTIKULATE_PARSER()) << "Expected to parse 'phonemes' element, aborting here";
         ok = false;
         return ids;
@@ -256,7 +249,7 @@ QStringList CourseParser::parsePhonemeIds(QXmlStreamReader &xml, bool &ok)
         xml.readNext();
         if (xml.tokenType() == QXmlStreamReader::StartElement) {
             if (xml.name() == "phonemeID") {
-                bool elementOk{ false };
+                bool elementOk {false};
                 ids.append(parseElement(xml, elementOk));
                 ok &= elementOk;
             } else {
@@ -267,7 +260,7 @@ QStringList CourseParser::parsePhonemeIds(QXmlStreamReader &xml, bool &ok)
     return ids;
 }
 
-QString CourseParser::parseElement(QXmlStreamReader& xml, bool &ok)
+QString CourseParser::parseElement(QXmlStreamReader &xml, bool &ok)
 {
     ok = true;
     if (xml.tokenType() != QXmlStreamReader::StartElement) {
@@ -283,8 +276,7 @@ QString CourseParser::parseElement(QXmlStreamReader& xml, bool &ok)
     return xml.text().toString();
 }
 
-
-QDomDocument CourseParser::serializedDocument(ICourse *course, bool trainingExport)
+QDomDocument CourseParser::serializedDocument(std::shared_ptr<IEditableCourse> course, bool trainingExport)
 {
     QDomDocument document;
     // prepare xml header
@@ -317,14 +309,14 @@ QDomDocument CourseParser::serializedDocument(ICourse *course, bool trainingExpo
         unitTitleElement.appendChild(document.createTextNode(unit->title()));
 
         // construct phrases
-        for (Phrase *phrase : unit->phraseList()) {
+        for (auto &phrase : unit->phrases()) {
             if (trainingExport && phrase->soundFileUrl().isEmpty()) {
                 continue;
             }
-            unitPhraseListElement.appendChild(serializedPhrase(phrase, document));
+            unitPhraseListElement.appendChild(serializedPhrase(std::static_pointer_cast<IEditablePhrase>(phrase), document));
         }
 
-        if (trainingExport && unitPhraseListElement.childNodes().count() == 0) {
+        if (trainingExport && unitPhraseListElement.childNodes().isEmpty()) {
             continue;
         }
 
@@ -355,7 +347,7 @@ QDomDocument CourseParser::serializedDocument(ICourse *course, bool trainingExpo
     return document;
 }
 
-QDomElement CourseParser::serializedPhrase(Phrase *phrase, QDomDocument &document)
+QDomElement CourseParser::serializedPhrase(std::shared_ptr<IEditablePhrase> phrase, QDomDocument &document)
 {
     QDomElement phraseElement = document.createElement(QStringLiteral("phrase"));
     QDomElement phraseIdElement = document.createElement(QStringLiteral("id"));
@@ -374,7 +366,7 @@ QDomElement CourseParser::serializedPhrase(Phrase *phrase, QDomDocument &documen
     phraseEditStateElement.appendChild(document.createTextNode(phrase->editStateString()));
 
     // add phonemes
-    foreach (Phoneme *phoneme, phrase->phonemes()) {
+    for (auto &phoneme : phrase->phonemes()) {
         QDomElement phonemeElement = document.createElement(QStringLiteral("phonemeID"));
         phonemeElement.appendChild(document.createTextNode(phoneme->id()));
         phrasePhonemeListElement.appendChild(phonemeElement);
@@ -393,29 +385,21 @@ QDomElement CourseParser::serializedPhrase(Phrase *phrase, QDomDocument &documen
     phraseElement.appendChild(phraseEditStateElement);
     phraseElement.appendChild(phrasePhonemeListElement);
 
-    if (phrase->isExcluded()) {
-        QDomElement phraseIsExcludedElement = document.createElement(QStringLiteral("excluded"));
-        phraseIsExcludedElement.appendChild(document.createTextNode(QStringLiteral("true")));
-        phraseElement.appendChild(phraseIsExcludedElement);
-    }
-
     return phraseElement;
 }
 
-bool CourseParser::exportCourseToGhnsPackage(ICourse *course, const QString &exportPath)
+bool CourseParser::exportCourseToGhnsPackage(std::shared_ptr<IEditableCourse> course, const QString &exportPath)
 {
     // filename
     const QString fileName = course->id() + ".tar.bz2";
     KTar tar = KTar(exportPath + '/' + fileName, QStringLiteral("application/x-bzip"));
     if (!tar.open(QIODevice::WriteOnly)) {
-        qCWarning(ARTIKULATE_CORE()) << "Unable to open tar file"
-            << exportPath + '/' + fileName
-            << "in write mode, aborting.";
+        qCWarning(ARTIKULATE_CORE()) << "Unable to open tar file" << exportPath + '/' + fileName << "in write mode, aborting.";
         return false;
     }
 
-    for (auto unit : course->units()) {
-        for (auto *phrase : unit->phraseList()) {
+    for (auto &unit : course->units()) {
+        for (auto &phrase : unit->phrases()) {
             if (QFile::exists(phrase->soundFileUrl())) {
                 tar.addLocalFile(phrase->soundFileUrl(), phrase->id() + ".ogg");
             }
