@@ -19,21 +19,22 @@
  */
 
 #include "skeletonresource.h"
-#include "courseparser.h"
+#include "artikulate_debug.h"
 #include "core/language.h"
-#include "core/unit.h"
-#include "core/phrase.h"
-#include "editablecourseresource.h"
 #include "core/phoneme.h"
 #include "core/phonemegroup.h"
+#include "core/phrase.h"
+#include "core/unit.h"
+#include "courseparser.h"
+#include "editablecourseresource.h"
 #include <QDir>
-#include <QQmlEngine>
 #include <QDomDocument>
-#include <QIODevice>
-#include <QXmlStreamReader>
 #include <QFile>
 #include <QFileInfo>
-#include "artikulate_debug.h"
+#include <QIODevice>
+#include <QQmlEngine>
+#include <QUuid>
+#include <QXmlStreamReader>
 
 class SkeletonResourcePrivate
 {
@@ -62,11 +63,7 @@ public:
                 }
 
                 // quit reading when basic elements are read
-                if (!m_identifier.isEmpty()
-                    && !m_title.isEmpty()
-                    && !m_description.isEmpty()
-                )
-                {
+                if (!m_identifier.isEmpty() && !m_title.isEmpty() && !m_description.isEmpty()) {
                     break;
                 }
             }
@@ -95,8 +92,8 @@ public:
     QString m_identifier;
     QString m_title;
     QString m_description;
-    bool m_unitsParsed{ false };
-    bool m_modified{ false };
+    bool m_unitsParsed {false};
+    bool m_modified {false};
 
 protected:
     QVector<std::shared_ptr<Unit>> m_units; ///!< the units variable is loaded lazily and shall never be access directly
@@ -110,7 +107,7 @@ QVector<std::shared_ptr<Unit>> SkeletonResourcePrivate::units()
     auto units = CourseParser::parseUnits(m_path);
     for (auto &unit : units) {
         Q_ASSERT(m_self.lock() != nullptr);
-        unit->setCourse(m_self.lock().get());
+        unit->setCourse(m_self.lock());
         m_units.append(std::move(unit));
     }
     m_unitsParsed = true;
@@ -123,7 +120,7 @@ std::shared_ptr<Unit> SkeletonResourcePrivate::appendUnit(std::shared_ptr<Unit>
     m_units.append(unit);
     m_modified = true;
     Q_ASSERT(m_self.lock() != nullptr);
-    unit->setCourse(m_self.lock().get());
+    unit->setCourse(m_self.lock());
     return m_units.last();
 }
 
@@ -158,7 +155,7 @@ QDomDocument SkeletonResourcePrivate::serializedSkeleton()
         unitTitleElement.appendChild(document.createTextNode(unit->title()));
 
         // construct phrases
-        for (Phrase *phrase : unit->phraseList()) {
+        for (auto &phrase : unit->phrases()) {
             QDomElement phraseElement = document.createElement(QStringLiteral("phrase"));
             QDomElement phraseIdElement = document.createElement(QStringLiteral("id"));
             QDomElement phraseTextElement = document.createElement(QStringLiteral("text"));
@@ -203,17 +200,11 @@ SkeletonResource::SkeletonResource(const QUrl &path, IResourceRepository *reposi
     , d(new SkeletonResourcePrivate(path))
 {
     QQmlEngine::setObjectOwnership(this, QQmlEngine::CppOwnership);
-    connect(this, &SkeletonResource::idChanged, this, [=]() {
-        d->m_modified = true;
-    });
-    connect(this, &SkeletonResource::titleChanged, this, [=]() {
-        d->m_modified = true;
-    });
-    connect(this, &SkeletonResource::descriptionChanged, this, [=]() {
-        d->m_modified = true;
-    });
+    connect(this, &SkeletonResource::idChanged, this, [=]() { d->m_modified = true; });
+    connect(this, &SkeletonResource::titleChanged, this, [=]() { d->m_modified = true; });
+    connect(this, &SkeletonResource::descriptionChanged, this, [=]() { d->m_modified = true; });
 
-    Q_UNUSED(repository);
+    Q_UNUSED(repository)
 }
 
 SkeletonResource::~SkeletonResource() = default;
@@ -249,7 +240,7 @@ QString SkeletonResource::foreignId() const
 
 void SkeletonResource::setForeignId(QString id)
 {
-    Q_UNUSED(id);
+    Q_UNUSED(id)
     Q_UNREACHABLE();
 }
 
@@ -275,7 +266,7 @@ QString SkeletonResource::i18nTitle() const
 
 void SkeletonResource::setI18nTitle(QString title)
 {
-    Q_UNUSED(title);
+    Q_UNUSED(title)
     Q_UNREACHABLE();
 }
 
@@ -297,14 +288,14 @@ bool SkeletonResource::exportToFile(const QUrl &filePath) const
 {
     // write back to file
     // create directories if necessary
-    QFileInfo info(filePath.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path());
+    QFileInfo info(filePath.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path());
     if (!info.exists()) {
         qCDebug(ARTIKULATE_LOG()) << "create xml output file directory, not existing";
         QDir dir;
-        dir.mkpath(filePath.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path());
+        dir.mkpath(filePath.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path());
     }
 
-    //TODO port to atomic file swap
+    // TODO port to atomic file swap
     QFile file(filePath.toLocalFile());
     if (!file.open(QIODevice::WriteOnly)) {
         qCWarning(ARTIKULATE_LOG()) << "Unable to open file " << filePath << " in write mode, aborting.";
@@ -315,7 +306,67 @@ bool SkeletonResource::exportToFile(const QUrl &filePath) const
     return true;
 }
 
-std::shared_ptr<Unit> SkeletonResource::addUnit(std::unique_ptr<Unit> unit)
+bool SkeletonResource::createPhraseAfter(IPhrase *previousPhrase)
+{
+    std::shared_ptr<Unit> parentUnit = units().last();
+    if (previousPhrase) {
+        for (const auto &unit : units()) {
+            if (previousPhrase->unit()->id() == unit->id()) {
+                parentUnit = unit;
+                break;
+            }
+        }
+    }
+
+    // find index
+    int index = parentUnit->phrases().size();
+    for (int i = 0; i < parentUnit->phrases().size(); ++i) {
+        if (parentUnit->phrases().at(i)->id() == previousPhrase->id()) {
+            index = i;
+            break;
+        }
+    }
+
+    // find globally unique phrase id inside course
+    QStringList phraseIds;
+    for (auto unit : units()) {
+        for (auto &phrase : unit->phrases()) {
+            phraseIds.append(phrase->id());
+        }
+    }
+    QString id = QUuid::createUuid().toString();
+    while (phraseIds.contains(id)) {
+        id = QUuid::createUuid().toString();
+        qCWarning(ARTIKULATE_LOG) << "Phrase id generator has found a collision, recreating id.";
+    }
+
+    // create unit
+    std::shared_ptr<Phrase> phrase = Phrase::create();
+    phrase->setId(id);
+    phrase->setText(QString());
+    phrase->setType(IPhrase::Type::Word);
+    parentUnit->addPhrase(phrase, index);
+
+    return true;
+}
+
+bool SkeletonResource::deletePhrase(IPhrase *phrase)
+{
+    Q_ASSERT(phrase);
+    if (!phrase) {
+        return false;
+    }
+    auto unitId = phrase->unit()->id();
+    for (auto &unit : d->units()) {
+        if (unit->id() == unitId) {
+            unit->removePhrase(phrase->self());
+            return true;
+        }
+    }
+    return false;
+}
+
+std::shared_ptr<Unit> SkeletonResource::addUnit(std::shared_ptr<Unit> unit)
 {
     std::shared_ptr<Unit> storedUnit(std::move(unit));
     emit unitAboutToBeAdded(storedUnit, d->units().count() - 1);
@@ -353,9 +404,14 @@ std::shared_ptr<ILanguage> SkeletonResource::language() const
     return std::shared_ptr<Language>();
 }
 
+QString SkeletonResource::languageTitle() const
+{
+    return QString();
+}
+
 void SkeletonResource::setLanguage(std::shared_ptr<ILanguage> language)
 {
-    Q_UNUSED(language);
+    Q_UNUSED(language)
     Q_UNREACHABLE();
 }
 
