@@ -23,31 +23,48 @@
 #include "phrase.h"
 
 #include <QMap>
-#include <QList>
-#include <QSignalMapper>
+#include <QQmlEngine>
 #include <QStringList>
 #include <QUuid>
-#include <QQmlEngine>
 
 #include "artikulate_debug.h"
 #include <KLocalizedString>
 #include <QUrl>
 
 Unit::Unit(QObject *parent)
-    : QObject(parent)
-    , m_course(nullptr)
-    , m_phraseSignalMapper(new QSignalMapper(this))
+    : IEditableUnit(parent)
 {
     QQmlEngine::setObjectOwnership(this, QQmlEngine::CppOwnership);
 }
 
-Unit::~Unit()
+Unit::~Unit() = default;
+
+std::shared_ptr<Unit> Unit::create()
 {
-    for (auto phrase : m_phrases) {
-        phrase->deleteLater();
-    }
-    m_phrases.clear();
-    m_phraseSignalMapper->deleteLater();
+    std::shared_ptr<Unit> unit(new Unit);
+    unit->setSelf(unit);
+    std::weak_ptr<Unit> unitParameter = unit;
+    connect(unit.get(), &IUnit::phraseAdded, unit.get(), [unitParameter](){
+        if (auto unit = unitParameter.lock()) {
+            unit->emitPhrasesChanged(unit);
+        }
+    });
+    connect(unit.get(), &IUnit::phraseRemoved, unit.get(), [unitParameter](){
+        if (auto unit = unitParameter.lock()) {
+            unit->emitPhrasesChanged(unit);
+        }
+    });
+    return unit;
+}
+
+void Unit::setSelf(std::shared_ptr<IUnit> self)
+{
+    m_self = self;
+}
+
+std::shared_ptr<IUnit> Unit::self() const
+{
+    return m_self.lock();
 }
 
 QString Unit::id() const
@@ -74,14 +91,14 @@ void Unit::setForeignId(const QString &id)
     m_foreignId = id;
 }
 
-ICourse *Unit::course() const
+std::shared_ptr<ICourse> Unit::course() const
 {
-    return m_course;
+    return m_course.lock();
 }
 
-void Unit::setCourse(ICourse *course)
+void Unit::setCourse(std::shared_ptr<ICourse> course)
 {
-    if (course == m_course) {
+    if (course == m_course.lock()) {
         return;
     }
     m_course = course;
@@ -102,12 +119,12 @@ void Unit::setTitle(const QString &title)
     }
 }
 
-QList<Phrase*> Unit::phraseList() const
+QVector<std::shared_ptr<IPhrase>> Unit::phrases() const
 {
     return m_phrases;
 }
 
-void Unit::addPhrase(Phrase *phrase)
+void Unit::addPhrase(std::shared_ptr<IEditablePhrase> phrase, int index)
 {
     auto iter = m_phrases.constBegin();
     while (iter != m_phrases.constEnd()) {
@@ -117,51 +134,31 @@ void Unit::addPhrase(Phrase *phrase)
         }
         ++iter;
     }
-    phrase->setUnit(this);
-    emit phraseAboutToBeAdded(phrase, m_phrases.length());
-    m_phrases.append(phrase);
-    m_phraseSignalMapper->setMapping(phrase, phrase->id());
-
+    phrase->setUnit(m_self.lock());
+    emit phraseAboutToBeAdded(phrase, index);
+    m_phrases.insert(index, phrase);
     emit phraseAdded(phrase);
 
-    connect(phrase, &Phrase::typeChanged, m_phraseSignalMapper,
-        static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-    connect(phrase, &Phrase::modified, this, &Unit::modified);
-
+    connect(phrase.get(), &Phrase::modified, this, &Unit::modified);
     emit modified();
 }
 
-QList<Phrase *> Unit::excludedSkeletonPhraseList() const
+void Unit::removePhrase(std::shared_ptr<IPhrase> phrase)
 {
-    QList<Phrase *> excludedPhraseList;
-    for (auto phrase : m_phrases) {
-        if (phrase->isExcluded() == true) {
-            excludedPhraseList.append(phrase);
+    int index = -1;
+    for (int i = 0; i < m_phrases.count(); ++i) {
+        if (m_phrases.at(i)->id() == phrase->id()) {
+            index = i;
+            break;
         }
     }
-    return excludedPhraseList;
+    Q_ASSERT(index >= 0);
+    emit phraseAboutToBeRemoved(index);
+    m_phrases.removeAt(index);
+    emit phraseRemoved();
 }
 
-void Unit::excludeSkeletonPhrase(const QString &phraseId)
+void Unit::emitPhrasesChanged(std::shared_ptr<IEditableUnit> unit)
 {
-    for (auto phrase : m_phrases) {
-        if (phrase->id() == phraseId) {
-            phrase->setExcluded(true);
-            emit modified();
-            return;
-        }
-    }
-    qCWarning(ARTIKULATE_LOG) << "Could not exclude phrase with ID " << phraseId << ", no phrase with this ID.";
-}
-
-void Unit::includeSkeletonPhrase(const QString &phraseId)
-{
-    for (auto phrase : m_phrases) {
-        if (phrase->id() == phraseId) {
-            phrase->setExcluded(false);
-            emit modified();
-            return;
-        }
-    }
-    qCWarning(ARTIKULATE_LOG) << "Could not include phrase with ID " << phraseId << ", no phrase with this ID.";
+    emit phrasesChanged(unit);
 }
