@@ -22,68 +22,53 @@
 #define UNIT_H
 
 #include "artikulatecore_export.h"
-#include <memory>
+#include "ieditableunit.h"
 #include <QObject>
-#include <QList>
-#include <QVector>
 #include <QStringList>
+#include <QVector>
+#include <memory>
 
-class QSignalMapper;
 class QString;
 class Phrase;
+class IPhrase;
 class ICourse;
 
-class ARTIKULATECORE_EXPORT Unit : public QObject
+class ARTIKULATECORE_EXPORT Unit : public IEditableUnit
 {
     Q_OBJECT
     Q_PROPERTY(QString id READ id WRITE setId NOTIFY idChanged)
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
-    Q_PROPERTY(ICourse *course READ course WRITE setCourse NOTIFY courseChanged)
 
 public:
+    static std::shared_ptr<Unit> create();
+    ~Unit() override;
+
+    QString id() const override;
+    void setId(const QString &id) override;
+    QString foreignId() const override;
+    void setForeignId(const QString &id) override;
+    std::shared_ptr<ICourse> course() const override;
+    void setCourse(std::shared_ptr<ICourse> course) override;
+    QString title() const override;
+    void setTitle(const QString &title) override;
+    QVector<std::shared_ptr<IPhrase>> phrases() const override;
+    void addPhrase(std::shared_ptr<IEditablePhrase> phrase, int index) override;
+    void removePhrase(std::shared_ptr<IPhrase> phrase) override;
+    std::shared_ptr<IUnit> self() const override;
+    void emitPhrasesChanged(std::shared_ptr<IEditableUnit> unit);
+
+protected:
     explicit Unit(QObject *parent = nullptr);
-    ~Unit();
-
-    QString id() const;
-    void setId(const QString &id);
-    QString foreignId() const;
-    void setForeignId(const QString &id);
-    ICourse * course() const;
-    void setCourse(ICourse* course);
-    QString title() const;
-    void setTitle(const QString &title);
-    QList<Phrase*> phraseList() const;
-    void addPhrase(Phrase *phrase);
-    QList<Phrase *> excludedSkeletonPhraseList() const;
-
-    /**
-     * Removes phrase with ID \p phraseId from unit and adds ID to set
-     * of excluded IDs.
-     *
-     * \param phraseId is the UID of the to be excluded phrase
-     */
-    Q_INVOKABLE void excludeSkeletonPhrase(const QString &phraseId);
-    Q_INVOKABLE void includeSkeletonPhrase(const QString &phraseId);
-
-Q_SIGNALS:
-    void idChanged();
-    void titleChanged();
-    void courseChanged();
-    void displayPhraseTypeChanged();
-    void modified();
-    void phraseAdded(Phrase*);
-    void phraseAboutToBeAdded(Phrase*,int);
-    void phraseRemoved(Phrase*);
-    void phraseAboutToBeRemoved(int,int);
 
 private:
+    void setSelf(std::shared_ptr<IUnit> self) override;
     Q_DISABLE_COPY(Unit)
+    std::weak_ptr<IUnit> m_self;
     QString m_id;
     QString m_foreignId;
-    ICourse *m_course;
+    std::weak_ptr<ICourse> m_course;
     QString m_title;
-    QList<Phrase*> m_phrases;
-    QSignalMapper *m_phraseSignalMapper;
+    QVector<std::shared_ptr<IPhrase>> m_phrases;
 };
 
 #endif // UNIT_H
