@@ -21,20 +21,18 @@
 #ifndef MAINWINDOW_EDITOR_H
 #define MAINWINDOW_EDITOR_H
 
-#include <KXmlGuiWindow>
-#include <QQuickWidget>
 #include "core/contributorrepository.h"
 #include "core/trainingsession.h"
+#include <QQmlApplicationEngine>
 
 class EditorSession;
 class QQuickWidget;
 
-class MainWindowEditor : public KXmlGuiWindow
+class MainWindowEditor : public QQmlApplicationEngine
 {
     Q_OBJECT
 
 public:
-
     /**
      * Default Constructor
      */
@@ -45,26 +43,21 @@ public:
      */
     virtual ~MainWindowEditor();
 
-    ContributorRepository * resourceRepository() const;
+    ContributorRepository *resourceRepository() const;
 
     void setupActions();
 
-    QSize sizeHint() const override { return QSize(1000, 700); }
-
-    bool queryClose() override;
-
 public Q_SLOTS:
     void showSettingsDialog();
     void save();
     void quit();
 
 Q_SIGNALS:
-     void modeChanged(bool);
+    void modeChanged(bool);
 
 private:
     ContributorRepository *m_repository;
     EditorSession *m_editorSession;
-    QQuickWidget *m_widget;
 };
 
 #endif
