@@ -33,16 +33,11 @@ class LanguageModel : public QSortFilterProxyModel
     Q_PROPERTY(LanguageResourceView view READ view WRITE setView NOTIFY viewChanged)
 
 public:
-    enum LanguageResourceView {
-        NonEmptyContributorOnlyResources,
-        NonEmptyGhnsOnlyLanguages,
-        NonEmptyLanguages,
-        AllLanguages
-    };
+    enum LanguageResourceView { NonEmptyContributorOnlyResources, NonEmptyGhnsOnlyLanguages, NonEmptyLanguages, AllLanguages };
     Q_ENUM(LanguageResourceView)
 
     explicit LanguageModel(QObject *parent = nullptr);
-    LanguageResourceModel * resourceModel() const;
+    LanguageResourceModel *resourceModel() const;
     void setResourceModel(LanguageResourceModel *resourceModel);
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
     void setView(LanguageResourceView view);
