@@ -59,27 +59,19 @@ void SkeletonModel::setResourceRepository(IEditableRepository *repository)
     beginResetModel();
 
     if (m_repository) {
-        disconnect(m_repository, &IEditableRepository::skeletonAboutToBeAdded, this,
-            &SkeletonModel::onSkeletonAboutToBeAdded);
-        disconnect(m_repository, &IEditableRepository::skeletonAdded, this,
-            &SkeletonModel::onSkeletonAdded);
-        disconnect(m_repository, &IEditableRepository::skeletonAboutToBeRemoved, this,
-            &SkeletonModel::onSkeletonAboutToBeRemoved);
-        disconnect(m_repository, &IEditableRepository::skeletonRemoved, this,
-            &SkeletonModel::onSkeletonRemoved);
+        disconnect(m_repository, &IEditableRepository::skeletonAboutToBeAdded, this, &SkeletonModel::onSkeletonAboutToBeAdded);
+        disconnect(m_repository, &IEditableRepository::skeletonAdded, this, &SkeletonModel::onSkeletonAdded);
+        disconnect(m_repository, &IEditableRepository::skeletonAboutToBeRemoved, this, &SkeletonModel::onSkeletonAboutToBeRemoved);
+        disconnect(m_repository, &IEditableRepository::skeletonRemoved, this, &SkeletonModel::onSkeletonRemoved);
     }
 
     m_repository = repository;
 
     if (m_repository) {
-        connect(m_repository, &IEditableRepository::skeletonAboutToBeAdded, this,
-            &SkeletonModel::onSkeletonAboutToBeAdded);
-        connect(m_repository, &IEditableRepository::skeletonAdded, this,
-            &SkeletonModel::onSkeletonAdded);
-        connect(m_repository, &IEditableRepository::skeletonAboutToBeRemoved, this,
-            &SkeletonModel::onSkeletonAboutToBeRemoved);
-        connect(m_repository, &IEditableRepository::skeletonRemoved, this,
-            &SkeletonModel::onSkeletonRemoved);
+        connect(m_repository, &IEditableRepository::skeletonAboutToBeAdded, this, &SkeletonModel::onSkeletonAboutToBeAdded);
+        connect(m_repository, &IEditableRepository::skeletonAdded, this, &SkeletonModel::onSkeletonAdded);
+        connect(m_repository, &IEditableRepository::skeletonAboutToBeRemoved, this, &SkeletonModel::onSkeletonAboutToBeRemoved);
+        connect(m_repository, &IEditableRepository::skeletonRemoved, this, &SkeletonModel::onSkeletonRemoved);
     }
 
     if (m_repository) {
@@ -87,7 +79,7 @@ void SkeletonModel::setResourceRepository(IEditableRepository *repository)
         for (int i = 0; i < skeletons.count(); ++i) {
             auto skeleton = skeletons.at(i);
             // TODO only title changed is connected, change this to a general changed signal
-            auto connection = connect(skeleton.get(), &IEditableCourse::titleChanged, this, [=](){
+            auto connection = connect(skeleton.get(), &IEditableCourse::titleChanged, this, [=]() {
                 const auto row = m_repository->skeletons().indexOf(skeleton);
                 emit dataChanged(index(row, 0), index(row, 0));
             });
@@ -98,7 +90,7 @@ void SkeletonModel::setResourceRepository(IEditableRepository *repository)
     endResetModel();
 }
 
-IEditableRepository * SkeletonModel::resourceRepository() const
+IEditableRepository *SkeletonModel::resourceRepository() const
 {
     return m_repository;
 }
@@ -116,21 +108,20 @@ QVariant SkeletonModel::data(const QModelIndex &index, int role) const
     auto skeleton = m_repository->skeletons().at(index.row());
 
     switch (role) {
-    case Qt::DisplayRole:
-        return !skeleton->title().isEmpty() ? QVariant(skeleton->title())
-                                            : QVariant(i18nc("@item:inlistbox:", "unknown"));
-    case Qt::ToolTipRole:
-        return QVariant(skeleton->title());
-    case TitleRole:
-        return skeleton->title();
-    case DescriptionRole:
-        return skeleton->description();
-    case IdRole:
-        return skeleton->id();
-    case DataRole:
-        return QVariant::fromValue<QObject *>(skeleton.get());
-    default:
-        return QVariant();
+        case Qt::DisplayRole:
+            return !skeleton->title().isEmpty() ? QVariant(skeleton->title()) : QVariant(i18nc("@item:inlistbox:", "unknown"));
+        case Qt::ToolTipRole:
+            return QVariant(skeleton->title());
+        case TitleRole:
+            return skeleton->title();
+        case DescriptionRole:
+            return skeleton->description();
+        case IdRole:
+            return skeleton->id();
+        case DataRole:
+            return QVariant::fromValue<QObject *>(skeleton.get());
+        default:
+            return QVariant();
     }
 }
 
@@ -145,7 +136,7 @@ int SkeletonModel::rowCount(const QModelIndex &) const
 void SkeletonModel::onSkeletonAboutToBeAdded(std::shared_ptr<IEditableCourse> skeleton, int row)
 {
     beginInsertRows(QModelIndex(), row, row);
-    auto connection = connect(skeleton.get(), &IEditableCourse::titleChanged, this, [=](){
+    auto connection = connect(skeleton.get(), &IEditableCourse::titleChanged, this, [=]() {
         const auto row = m_repository->courses().indexOf(skeleton);
         emit dataChanged(index(row, 0), index(row, 0));
     });
